pub enum Value {
Null,
I64(i64),
U64(u64),
F64(f64),
Date(Date),
Time(Time),
DateTime(DateTime),
DateTimeTz(DateTimeTz),
Uuid([u8; 16]),
Bytes(Vec<u8>),
String(String),
}Expand description
An owned database value.
This is the common value representation used by the facade when rows are collected or when parameters need to be stored independently of borrowed input data.
Variants
Null
A SQL null.
I64(i64)
A signed integer.
U64(u64)
An unsigned integer.
F64(f64)
A floating-point value.
Date(Date)
A date without a time of day.
Time(Time)
A time of day with microsecond precision.
DateTime(DateTime)
A date and time without an offset.
DateTimeTz(DateTimeTz)
A date and time with an offset in seconds.
Uuid([u8; 16])
A 16-byte uuid value.
Bytes(Vec<u8>)
Binary data.
String(String)
Text data.