pub struct Transaction<'a> { /* private fields */ }Expand description
A transaction on a Connection connection.
Dropping a transaction before commit or rollback follows the behavior of the selected driver.
While the transaction is alive, it keeps the Connection borrowed.
Implementations